@@ -2,10 +2,10 @@ package Sereal;
 use 5.008;
 use strict;
 use warnings;
-our $VERSION = '2.12';
+our $VERSION = '3.000_002';
 our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
-use Sereal::Encoder 2.12 qw(encode_sereal sereal_encode_with_object);
-use Sereal::Decoder 2.12 qw(decode_sereal looks_like_sereal sereal_decode_with_object);
+use Sereal::Encoder 3.000_002 qw(encode_sereal sereal_encode_with_object);
+use Sereal::Decoder 3.000_002 qw(decode_sereal looks_like_sereal sereal_decode_with_object);
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
